<?php

/**
 * mod_smenu_position
 *
 * @version 2.0
 * @author Creative Pulse
 * @copyright Creative Pulse 2009
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link http://www.creativepulse.eu
 */

defined('_JEXEC') or die('Restricted access');


class ModSmenuPosition {

	function instance_id($new = false) {
		static $num = 0;

		if ($new)
			$num++;
		else
			return $num;
	}

	function json_esc($input, $esc_lt_gt = true) {
		$result = '';
		$input = (string) $input;
		$conv = array( "'" => "'", '"' => '"', '&' => '&', '\\' => '\\', "\n" => 'n', "\r" => 'r', "\t" => 't', "\b" => 'b', "\f" => 'f' );

		if ($esc_lt_gt)
			$conv = array_merge($conv, array( '<' => 'u003C', '>' => 'u003E' ));

		for ($i = 0, $len = strlen($input); $i < $len; $i++)
			$result .= isset($conv[$input{$i}]) ? '\\' . $conv[$input{$i}] : $input{$i};

		return $result;
	}

	function norm_list($input, &$default, &$list) {
		$input = trim($input);
		$first = true;
		if ($input != '')
			foreach (explode(',', $input) as $v) {
				$v = trim($v);
				if ($first) {
					$first = false;
					$default = $v;
				}
				else {
					$list[] = $v;
				}
			}
	}

	function def_int($input, $default = 0) {
		$input = trim($input);
		return $input == '' || !ctype_digit($input) ? $default : (int) $input;
	}

	function def_float($input, $default = 0.0) {
		$input = trim($input);
		return !preg_match('/^[0-9]+(\.[0-9]*)?$/', $input) ? $default : (float) $input;
	}

	function fmt_filename($filename) {
		$filename = str_replace('\\', '/', $filename);
		if ($filename{0} == '/')
			$filename = substr($filename, 1);

		if (substr($filename, -1) == '/')
			$filename = substr($filename, 0, -1);

		return $filename;
	}

	function prepare(&$params) {
		$this->posname = trim($params->get('posname'), '');
		$this->loadit = $this->posname != '';

		if ($this->loadit) {
			$this->instance_id(true);

			$width = $this->def_int($params->get('width'));
			$height = $this->def_int($params->get('height'));

			if ($width == 0 && $height == 0)
				$height = 100;

			$this->div_str = '';

			if ($width > 0)
				$this->div_str .= 'width:' . $width . 'px;';

			if ($height > 0)
				$this->div_str .= 'height:' . $height . 'px;';

			if ($this->div_str != '')
				$this->div_str = ' style="' . $this->div_str . '"';

			$this->interval = $this->def_int($params->get('interval'), 20);
			$this->speed = $this->def_float($params->get('speed'), 3);
			$this->minstep = $this->def_int($params->get('minstep'));
			$this->maxstep = $this->def_int($params->get('maxstep'));
			$this->hor_v = $params->get('orientation', 'horizontal') == 'horizontal';
			$this->hor = $this->hor_v ? 'true' : 'false';
			$this->align = $this->def_int($params->get('align'));
			$this->movtype = $params->get('movtype', 'plastic');
			$this->anitype = $params->get('anitype', 'static');
			$this->min_size = $this->def_int($params->get('min_size'));
			$this->large_size = $this->def_int($params->get('large_size'));
			$padding_input = $params->get('padding');
			$this->sel_permanent = $this->def_int($params->get('sel_permanent'), 1) ? 'true' : 'false';
			$this->img_start = trim($params->get('img_start'));
			$this->css_start = trim($params->get('css_start'));
			$this->img_split = trim($params->get('img_split'));
			$this->css_split = trim($params->get('css_split'));
			$this->img_end = trim($params->get('img_end'));
			$this->css_end = trim($params->get('css_end'));
			$this->def_item = $this->def_int($params->get('def_item'));

			preg_match_all('/(\d+)/', $padding_input, $m);
			if (count($m[0]) == 1)
				$this->padding = '[' . $m[1][0] . ', ' . $m[1][0] . ', ' . $m[1][0] . ', ' . $m[1][0] . ']';
			else
				$this->padding = '[' . intval(@$m[1][0]) . ', ' . intval(@$m[1][1]) . ', ' . intval(@$m[1][2]) . ', ' . intval(@$m[1][3]) . ']';

			$split_type = $params->get('split_type');
			if ($split_type == 'header_start')
				$def_select = 1;
			else if ($split_type == 'header_end')
				$def_select = -1;
			else
				$def_select = 0;

			$this->def_classes = '';

			$default = '';
			$this->outer_class_norm_list = array();
			$this->norm_list($params->get('def_outer_class_norm'), $default, $this->outer_class_norm_list);
			if (!empty($default))
				$this->def_classes .= '		def_outer_class_norm: "' . $default . '",' . "\n";

			$default = '';
			$this->outer_class_sel_list = array();
			$this->norm_list($params->get('def_outer_class_sel'), $default, $this->outer_class_sel_list);
			if (!empty($default))
				$this->def_classes .= '		def_outer_class_sel: "' . $default . '",' . "\n";

			$default = '';
			$this->inner_class_norm_list = array();
			$this->norm_list($params->get('def_inner_class_norm'), $default, $this->inner_class_norm_list);
			if (!empty($default))
				$this->def_classes .= '		def_inner_class_norm: "' . $default . '",' . "\n";

			$default = '';
			$this->inner_class_sel_list = array();
			$this->norm_list($params->get('def_inner_class_sel'), $default, $this->inner_class_sel_list);
			if (!empty($default))
				$this->def_classes .= '		def_inner_class_sel: "' . $default . '",' . "\n";

			$default = '';
			$this->split_image_list = array();
			$this->norm_list($params->get('img_split'), $default, $this->split_image_list);
			if (!empty($default)) {
				$this->def_split_image = $this->fmt_filename($default);

				if (file_exists(JPATH_SITE . '/' . $this->def_split_image)) {
					if (is_dir(JPATH_SITE . '/' . $this->def_split_image)) {
						$this->split_image_list = array();
						if ($dp = opendir(JPATH_SITE . '/' . $this->def_split_image)) {
							while (false !== ($file = readdir($dp))) {
								$ext = strtolower(strrchr($file, '.'));
								if ($ext == '.jpg' || $ext == '.jpeg' || $ext == '.png' || $ext == '.gif')
									$this->split_image_list[] = $this->def_split_image . '/' . $file;
							}
							closedir($dp);
							sort($this->split_image_list);
						}
						$this->def_split_image = '';
					}
				}
				else {
					$this->def_split_image = '';
				}
			}

			$default = '';
			$this->split_css_list = '';
			$this->norm_list($params->get('css_split'), $default, $this->split_css_list);
			if (!empty($default))
				$this->def_split_css = $default;


			if (strtolower($this->img_start) == 'list')
				$this->img_start = empty($this->split_image_list) ? '' : array_shift($this->split_image_list);

			if (strtolower($this->css_start) == 'list')
				$this->css_start = empty($this->split_css_list) ? $this->def_split_css : array_shift($this->split_css_list);

			$this->img_start = $this->make_image($this->img_start, $this->css_start, $def_select);

			if (strtolower($this->img_end) == 'list')
				$this->img_end = empty($this->split_image_list) ? '' : array_pop($this->split_image_list);

			if (strtolower($this->css_end) == 'list')
				$this->css_end = empty($this->split_css_list) ? $this->def_split_css : array_pop($this->split_css_list);

			$this->img_end = $this->make_image($this->img_end, $this->css_end, $def_select);


			$this->def_split_image = $this->make_image($this->def_split_image, $this->def_split_css, $def_select);

			$list = array();
			foreach ($this->split_image_list as $k => $v) {
				$item = $this->make_image($v, isset($this->split_css_list[$k]) ? $this->split_css_list[$k] : $this->def_split_css, $def_select);
				$list[] = $item == '' ? 'null' : $item;
			}
			$this->split_image_list = $list;
		}
	}

	function make_image($image, $css, $select = false) {
		$width = 0;
		$height = 0;
		$image = trim($image);

		if ($image != '' && strpos($image, '://') !== false)
			$image = '';

		if ($image != '') {
			$image = $this->fmt_filename($image);
			$image_path = JPATH_SITE . '/' . $image;
			if (file_exists($image_path)) {
				list($width, $height, $type, $attr) = getimagesize($image_path);
				$image = '<img src="' . htmlspecialchars(JURI::base() . $image) . '"';

				if ($this->hor_v && $width > 0)
					$image .= ' width="' . $width . '"';

				if (!$this->hor_v && $height > 0)
					$image .= ' height="' . $height . '"';

				$image .= ' />';

				$image = '{html: "' . $this->json_esc($image) . '"';

				if ($this->hor_v && $width > 0)
					$image .= ', size: ' . $width;

				if (!$this->hor_v && $height > 0)
					$image .= ', size: ' . $height;

				if ($select !== false)
					$image .= ', select: ' . $select;

				$image .= ', outer_class_norm: ""';
				$image .= ', outer_class_sel: ""';
				$image .= ', inner_class_norm: "' . $css . '"';
				$image .= ', inner_class_sel: ""';

				$image .= '}';
			}
			else {
				$image = '';
			}
		}

		return $image;
	}

}

?>